abacusai.code_suggestion_validation_response — AbacusAI documentation

# abacusai.code_suggestion_validation_response

## Classes

`CodeSuggestionValidationResponse` | A response from an LLM to validate a code suggestion.

## Module Contents

class abacusai.code_suggestion_validation_response.CodeSuggestionValidationResponse(client, isValid=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A response from an LLM to validate a code suggestion.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - isValid (bool) – Whether the code suggestion is valid.

  is_valid = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict